
import "mongoose";
import { mongoose } from "@typegoose/typegoose";

/**
 * Connects to the MongoDB database running on the default port.
 */
export function connect(): void {
    const url = "mongodb://localhost:27017/";
    const db = mongoose.connection;

    // Exit on error since program relies on db connection
    db.on('error', (err) => {
        // One weird issue with this is the connection takes a while to timeout
        console.error(err);
        process.exit(2);
    });

    mongoose.connect(url, {
        useNewUrlParser: true,
        useUnifiedTopology: true,
        useCreateIndex: true,
        dbName: "ml-test"
    });
}

/**
 * Defines the query operators for querying the mongodb. This is to make this a lot easier to pass the object to filter a value.
 * More here about it https://docs.mongodb.com/manual/reference/operator/query-logical/
 */
export interface QueryOperators {
    $eq?: any;
    $gt?: any;
    $gte?: any;
    $in?: any[];
    $lt?: any;
    $lte?: any;
    $ne?: any;
    $nin?: any[];
}
